list(
  rd_family_title = list(
    coerce = "Coercing objects:",
    dplyr.methods = "Other dplyr methods:",
    tidyr.method = "Other tidyr methods:",
    ggplot2.utils = "Other ggplot2 utils:",
    gradients = "Other gradient scales and palettes for hypsometry:"
  )
)
